@@ -117,7 +117,6 @@ class CockroachDBDialect(PGDialect_psycopg2):
         # often.
         super(PGDialect, self).initialize(connection)
         self.implicit_returning = True
-        self.supports_native_enum = False
         self.supports_smallserial = False
         self._backslash_escapes = False
         sversion = connection.scalar("select version()")
@@ -130,6 +129,7 @@ class CockroachDBDialect(PGDialect_psycopg2):
         self._has_native_json = self._is_v2plus
         self._has_native_jsonb = self._is_v2plus
         self._supports_savepoints = self._is_v201plus
+        self.supports_native_enum = self._is_v202plus
 
     def _get_server_version_info(self, conn):
         # PGDialect expects a postgres server version number here,
@@ -255,35 +255,27 @@ class CockroachDBDialect(PGDialect_psycopg2):
         return res
 
     def get_indexes(self, conn, table_name, schema=None, **kw):
+        if self._is_v192plus:
+            return super().get_indexes(conn, table_name, schema, **kw)
+
         # The Cockroach database creates a UNIQUE INDEX implicitly whenever the
         # UNIQUE CONSTRAINT construct is used. Currently we are just ignoring all unique indexes,
         # but we might need to return them and add an additional key `duplicates_constraint` if
         # it is detected as mirroring a constraint.
         # https://www.cockroachlabs.com/docs/stable/unique.html
         # https://github.com/sqlalchemy/sqlalchemy/blob/55f930ef3d4e60bed02a2dad16e331fe42cfd12b/lib/sqlalchemy/dialects/postgresql/base.py#L723
-        if not self._is_v2plus:
-            q = '''
-                SELECT
-                    "Name" as index_name,
-                    "Column" as column_name,
-                    "Unique" as unique,
-                    "Implicit" as implicit
-                FROM
-                    [SHOW INDEXES FROM "%(schema)s"."%(name)s"]
-            '''
-        else:
-            q = '''
-                SELECT
-                    index_name,
-                    column_name,
-                    (not non_unique::bool) as unique,
-                    implicit::bool as implicit
-                FROM
-                    information_schema.statistics
-                WHERE
-                    table_schema = %(schema)s
-                    AND table_name = %(name)s
-            '''
+        q = '''
+            SELECT
+                index_name,
+                column_name,
+                (not non_unique::bool) as unique,
+                implicit::bool as implicit
+            FROM
+                information_schema.statistics
+            WHERE
+                table_schema = %(schema)s
+                AND table_name = %(name)s
+        '''
         rows = conn.execute(q, schema=(schema or self.default_schema_name), name=table_name)
         indexes = collections.defaultdict(list)
         for row in rows:
